@@ -1,5 +1,5 @@
 /*
- * Copyright (c) [2011-2014] Novell, Inc.
+ * Copyright (c) [2011-2015] Novell, Inc.
  *
  * All Rights Reserved.
  *
@@ -44,7 +44,7 @@ namespace snapper
     {
     public:
 
-	explicit ConfigInfo(const string& config_name);
+	explicit ConfigInfo(const string& config_name, const string& root_prefix);
 
 	const string& getConfigName() const { return config_name; }
 	const string& getSubvolume() const { return subvolume; }
@@ -110,10 +110,10 @@ namespace snapper
     {
     public:
 
-	Snapper(const string& config_name = "root", bool disable_filters = false);
+	Snapper(const string& config_name, const string& root_prefix, bool disable_filters = false);
 	~Snapper();
 
-	string configName() const { return config_info->getConfigName(); }
+	const string& configName() const { return config_info->getConfigName(); }
 
 	string subvolumeDir() const;
 
@@ -125,42 +125,25 @@ namespace snapper
 
 	Snapshots::const_iterator getSnapshotCurrent() const;
 
-	Snapshots::iterator createSingleSnapshot(string description) __attribute__ ((deprecated));
-	Snapshots::iterator createPreSnapshot(string description) __attribute__ ((deprecated));
-	Snapshots::iterator createPostSnapshot(string description, Snapshots::const_iterator pre) __attribute__ ((deprecated));
+	Snapshots::iterator createSingleSnapshot(const SCD& scd);
+	Snapshots::iterator createSingleSnapshot(Snapshots::const_iterator parent, const SCD& scd);
+	Snapshots::iterator createSingleSnapshotOfDefault(const SCD& scd);
+	Snapshots::iterator createPreSnapshot(const SCD& scd);
+	Snapshots::iterator createPostSnapshot(Snapshots::const_iterator pre, const SCD& scd);
 
-	Snapshots::iterator createSingleSnapshot(uid_t uid, const string& description,
-						 const string& cleanup,
-						 const map<string, string>& userdata);
-	Snapshots::iterator createSingleSnapshot(Snapshots::const_iterator parent, bool read_only,
-						 uid_t uid, const string& description,
-						 const string& cleanup,
-						 const map<string, string>& userdata);
-	Snapshots::iterator createSingleSnapshotOfDefault(bool read_only, uid_t uid, const string& description,
-							  const string& cleanup,
-							  const map<string, string>& userdata);
-	Snapshots::iterator createPreSnapshot(uid_t uid, const string& description,
-					      const string& cleanup,
-					      const map<string, string>& userdata);
-	Snapshots::iterator createPostSnapshot(Snapshots::const_iterator pre, uid_t uid,
-					       const string& description, const string& cleanup,
-					       const map<string, string>& userdata);
-
-	void modifySnapshot(Snapshots::iterator snapshot, const string& description,
-			    const string& cleanup, const map<string, string>& userdata);
+	void modifySnapshot(Snapshots::iterator snapshot, const SMD& smd);
 
 	void deleteSnapshot(Snapshots::iterator snapshot);
 
 	const vector<string>& getIgnorePatterns() const { return ignore_patterns; }
 
-	static ConfigInfo getConfig(const string& config_name);
-	static list<ConfigInfo> getConfigs();
-	static void createConfig(const string& config_name, const string& subvolume,
-				 const string& fstype, const string& template_name);
-	static void createConfig(const string& config_name, const string& subvolume,
-				 const string& fstype, const string& template_name,
-				 bool add_fstab);
-	static void deleteConfig(const string& config_name);
+	static ConfigInfo getConfig(const string& config_name, const string& root_prefix);
+	static list<ConfigInfo> getConfigs(const string& root_prefix);
+
+	static void createConfig(const string& config_name, const string& root_prefix,
+				 const string& subvolume, const string& fstype,
+				 const string& template_name);
+	static void deleteConfig(const string& config_name, const string& root_prefix);
 
 	static bool detectFstype(const string& subvolume, string& fstype);
 
